/*
 * Copyright James Morse Y2K+1
 * This is GPLed software 
 * please read COPYING
 *
 */

#ifndef ERROR_H
#define ERROR_H

/* bug6.c */
#define EXIT_OK	0	/* exit no error */
#define EXIT_1	1	/* left main loop */
#define EXIT_2	2	/* stop is busted? */
#define CMDL_1	3	/* bad -s args */
#define CMDL_2	4	/* bad -r args */
#define CMDL_3	5	/* bad -g args */
#define GNU_L	6	/* GNU licnse */
#define CMDL_U	7	/* unknowen args */
#define BM_B6	8	/* bad malloc of world */

/* findbug.c */
#define FB_F	9	/* things are messed up bad */

/* mate_die.c */
#define ALL_D	10	/* all bugs are dead */

/* terrain.c */
#define BM_GT	11	/* bad malloc elevation map */

#endif /* ERROR_H */
